document.addEventListener('DOMContentLoaded', function() {
    // Mobile menu toggle
    const mobileMenu = document.querySelector('.mobile-menu');
    const navLinks = document.querySelector('.nav-links');
    
    mobileMenu.addEventListener('click', () => {
        navLinks.classList.toggle('active');
    });

    // Scenario selection and decision tree logic
    const scenarioCards = document.querySelectorAll('.scenario-card');
    const decisionDisplay = document.getElementById('decision-display');
    const choiceButtons = document.querySelectorAll('.choice');

    // Sample scenario data
    const scenarios = {
        'Business Ethics Dilemma': {
            initial: "A major client has requested you to modify financial reports. What do you do?",
            choices: {
                a: "Refuse and report to authorities",
                b: "Try to negotiate a legal alternative",
                c: "Seek internal guidance first"
            }
        },
        'Environmental Crisis': {
            initial: "A chemical spill threatens local water supply. How do you respond?",
            choices: {
                a: "Immediate public announcement",
                b: "Conduct thorough assessment first",
                c: "Contact environmental experts"
            }
        },
        'Tech Innovation Challenge': {
            initial: "Your AI model shows concerning bias. How do you proceed?",
            choices: {
                a: "Rebuild from scratch",
                b: "Implement bias mitigation",
                c: "Hybrid approach with human oversight"
            }
        }
    };

    // Handle scenario selection
    scenarioCards.forEach(card => {
        card.addEventListener('click', function() {
            const title = this.querySelector('h3').textContent;
            if (scenarios[title]) {
                decisionDisplay.innerHTML = `
                    <h3>${title}</h3>
                    <p>${scenarios[title].initial}</p>
                `;
                updateChoices(scenarios[title].choices);
            }
        });
    });

    // Update choice buttons
    function updateChoices(choices) {
        choiceButtons.forEach(button => {
            const choice = button.dataset.choice;
            if (choices[choice]) {
                button.textContent = choices[choice];
                button.style.display = 'block';
            } else {
                button.style.display = 'none';
            }
        });
    }

    // Handle choice selection
    choiceButtons.forEach(button => {
        button.addEventListener('click', function() {
            const choice = this.dataset.choice;
            const feedback = generateFeedback(choice);
            decisionDisplay.innerHTML += `
                <div class="feedback">
                    <p>${feedback}</p>
                </div>
            `;
        });
    });

    // Generate feedback based on choice
    function generateFeedback(choice) {
        const feedbacks = {
            a: "This approach prioritizes integrity and compliance but may have immediate business impacts.",
            b: "A balanced approach that seeks compromise while maintaining standards.",
            c: "A measured response that leverages available expertise and resources."
        };
        return feedbacks[choice] || "Consider the implications of your choice.";
    }

    // Smooth scroll for navigation
    document.querySelectorAll('a[href^="#"]').forEach(anchor => {
        anchor.addEventListener('click', function(e) {
            e.preventDefault();
            const target = document.querySelector(this.getAttribute('href'));
            if (target) {
                target.scrollIntoView({
                    behavior: 'smooth',
                    block: 'start'
                });
                navLinks.classList.remove('active');
            }
        });
    });
});
